Crate sdl3_ttf_src

Crate sdl3_ttf_src 

This crate contains the source code of the SDL3_ttf library. It’s used by the sdl3-ttf-sys crate when building from source.

Version 3.2.2 of this crate didn’t include updates to submodules for that version of SDL_ttf. Version 3.2.3 is the SDL_ttf 3.2.2 source with updated submodules. This fixes the vendored freetype not building with Cmake 4.

Constants

REVISION
Revision
REVISION_HASH
Hash part of the revision
REVISION_OFFSET
Offset from tag part of the revision
REVISION_TAG
Tag part of the revision
REVISION_TAG_BASE
Tag part of the revision without version
SOURCE_DIR
Location of the SDL3_ttf source code
VERSION
Version part of the revision